
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v6.007.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "ExtUtils::MakeMaker" => 0,
    "Module::Build" => "0.28"
  },
  "dist_abstract" => "Add Pod::Weaver section with all used modules from package excluding listed ones",
  "dist_author" => [
    "Milan Sorm <sorm\@is4u.cz>"
  ],
  "dist_name" => "Pod-Weaver-Section-Requires",
  "dist_version" => "0.03",
  "license" => "perl",
  "module_name" => "Pod::Weaver::Section::Requires",
  "recursive_test_files" => 1,
  "requires" => {
    "Class::Inspector" => 0,
    "Module::Extract::Use" => 0,
    "Module::Load" => 0,
    "Moose" => 0,
    "Pod::Elemental::Element::Nested" => 0,
    "Pod::Elemental::Element::Pod5::Command" => 0,
    "Pod::Weaver::Role::Section" => 0,
    "aliased" => 0,
    "strict" => 0,
    "warnings" => 0
  }
);


my %fallback_build_requires = (
  "Module::Build" => "0.28"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
